AabbPoint

Struct AabbPoint 

pub struct AabbPoint(pub DVec3);
A point based on Aabb, the number in each axis means the fraction of the size of the Aabb. (0, 0, 0) is the center point.

     +Y
     |
     |
     +----- +X
   /
+Z

Tuple Fields

0: DVec3

Implementations

Source

impl AabbPoint

pub const CENTER: Self

Center point, shorthand of Anchor(DVec3::ZERO).